@@ -16,8 +16,8 @@
 #include <config.h>
 #include <ucommon/ucommon.h>
 #include <ucommon/export.h>
-#include <sipwitch/service.h>
 #include <sipwitch/process.h>
+#include <sipwitch/service.h>
 #include <ctype.h>
 #include <errno.h>
 #include <stdarg.h>
@@ -157,10 +157,14 @@ void service::subscriber::write(char *str)
 			fsys::close(fs);
 }
 
-service::callback::callback(unsigned rl, const char *name) :
+service::callback::callback(int rl, const char *name) :
 OrderedObject()
 {
-	crit(rl < RUNLEVELS, "service runlevel invalid");
+	crit(rl < (int)RUNLEVELS, "service runlevel invalid");
+	if(rl < 0) {
+		rl += RUNLEVELS;
+		crit(rl > 0, "service runlevel invalid");
+	}
 	LinkedObject::enlist(&runlevels[rl]);
 	id = name;
 	active_flag = false;
@@ -173,6 +177,14 @@ service::callback::~callback()
 	LinkedObject::delist(&runlevels[runlevel]);
 }
 
+void service::callback::activating(MappedRegistry *rr)
+{
+}
+
+void service::callback::expiring(MappedRegistry *rr)
+{
+}
+
 void service::callback::snapshot(FILE *fp)
 {
 }
@@ -931,6 +943,34 @@ void service::dumpfile(const char *uid)
 	fclose(fp);
 }
 
+void service::activate(MappedRegistry *rr)
+{
+	unsigned rl = 0;
+	linked_pointer<callback> cb;
+
+	while(rl < RUNLEVELS) {
+		cb = callback::runlevels[rl++];
+		while(cb) {
+			cb->activating(rr);
+			cb.next();
+		}
+	}
+}
+
+void service::expire(MappedRegistry *rr)
+{
+	unsigned rl = 0;
+	linked_pointer<callback> cb;
+
+	while(rl < RUNLEVELS) {
+		cb = callback::runlevels[rl++];
+		while(cb) {
+			cb->expiring(rr);
+			cb.next();
+		}
+	}
+}
+
 void service::snapshot(const char *uid)
 {
 	assert(uid == NULL || *uid != 0);
